/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.sqoop.validation;

import org.junit.Test;

import static junit.framework.Assert.*;

/**
 *
 */
public class TestStatus {
  @Test
  public void testGetWorstStatus() {
    // Comparing itself with itself
    assertEquals(Status.FINE,
      Status.getWorstStatus(Status.FINE));
    assertEquals(Status.FINE,
      Status.getWorstStatus(Status.FINE, Status.FINE));
    assertEquals(Status.ACCEPTABLE,
      Status.getWorstStatus(Status.ACCEPTABLE, Status.ACCEPTABLE));
    assertEquals(Status.UNACCEPTABLE,
      Status.getWorstStatus(Status.UNACCEPTABLE, Status.UNACCEPTABLE));

    // Retriving the worst option
    assertEquals(Status.UNACCEPTABLE,
      Status.getWorstStatus(Status.FINE, Status.UNACCEPTABLE));
    assertEquals(Status.ACCEPTABLE,
      Status.getWorstStatus(Status.FINE, Status.ACCEPTABLE));
  }

  @Test
  public void testCanProceed() {
    assertTrue(Status.FINE.canProceed());
    assertTrue(Status.ACCEPTABLE.canProceed());
    assertFalse(Status.UNACCEPTABLE.canProceed());
  }
}
